{

=pod

=head1 NAME

Blogger::Manila

=head1 SUMMARY

 my $m = Blogger::Manila->new(
                              blogid=>"foobar.manilasites.com",
                              username=>"foobar\@momandpopisp.com",
                              password=>"****",
                             );

 my $post = "hello world.";
 my $mid  = $m->newPost(postbody=>\$post,publish=>1);

 print $mid,"\n" || croak $m->LastError();

=head1 DESCRIPTION

Blogger::Manila allows you to manage your Manila-based website using the Blogger API.

It is a subclass of Blogger.pm

=cut

package Blogger::Manila;
use strict;

use vars qw ( $VERSION @ISA );
$VERSION = 0.1.1;

@ISA = qw ( Blogger );
use Blogger;
use URI;

=pod

=head1 CONSTRUCTOR METHODS

=cut

=pod

=head2 Blogger::Manila->new(%args)

Accepts all the same arguments as the Blogger.pm constructor, plus :

=over 4

=item B<proxy>

The URI of the Manila -> Blogger XML-RPC server

=back

=cut

sub init {
    my $self = shift;
    my %args = @_;

    if (exists $args{'proxy'}) {
	$self->Proxy($args{'proxy'});
	delete $args{'proxy'};
    }

    return $self->Blogger::init(%args);
}

=pod

=head1 BLOGGER::MANILA PUBLIC METHODS

=cut

=head2 $pkg->Proxy($uri)

Get/set the URI of the Manila->Blogger proxy.

If no proxy is explicitly defined then the method determines the hostname for the Manila server using the current blogid.

"Just to clarify, the URI is /RPC2, even if your blogid (homepage url) is a sub-site url, like http://www.myserver.com/mysite/. It's never something like /mysite/RPC2." --Jake Savin (Userland)

=cut

sub Proxy {
    my $self  = shift;
    my $proxy = shift;

    if ($proxy) {
	$self->{"_proxy"} = $proxy;
	return $self->{"_proxy"};
    }

    if ($self->{"_proxy"}) {
	return $self->{"_proxy"};
    }
    
    if (my $blog = $self->BlogId()) {
	my $uri = URI->new($blog);
	$self->{"_proxy"} = $uri->scheme()."://".$uri->host()."/RPC2";
	return $self->{"_proxy"};
    }

  Error::Simple->record("Unable to determine proxy explicitly or by parsing blogid.");
    return undef;
}

=pod

=head2 $pkg->AppKey()

Returns true. Manila does not require a Blogger API key, but specifies something (anything) all the same.

=cut

sub AppKey {
    my $self = shift;
    return 1;
}

=pod

=head2 $pkg->MaxPostLength()

By default, returns undef. In other words, there is no max post length for Manila.

"As far as I know there is no max length for a post, certainly nothing you have to enforce on your end." --Dave Winer (Userland)

=cut

sub MaxPostLength {
    my $self = shift;
    return undef;
}

return 1;

=pod

=head1 TO DO 

=over 4

=back

=head1 VERSION

0.1.1

=head DATE

August 25, 2001

=head1 AUTHOR

Aaron Straup Cope

=head1 CHANGES

=head2 0.1.1

=over 4

=item

Modified Blogger::Manila.pm I<Proxy> method to conform to the way Manila servers do XML-RPC.

=item 

Added Blogger::Manila.pm I<MaxPostLength> method.

=item

Added Blogger::Manila.pm private I<init> method to handle possible proxy argument.

=item

Updated POD.

=back

=head2 0.1

=over 4

=item

Initial setup.

=back

=head1 SEE ALSO

L<Blogger>

http://frontier.userland.com/emulatingBloggerInManila

=head1 LICENSE

Copyright 2001, Aaron Straup Cope.

This is free software, you may use it and distribute it under the
same terms as Perl itself.

=cut

}







